@@ -23,7 +23,7 @@
 #include <iostream>
 #include <string>
 #include <sstream>
-#ifdef __APPLE__
+#if defined (__APPLE__) || (__FreeBSD__)
 #include <ncurses.h>
 #else
 #include <ncursesw/ncurses.h>
@@ -437,7 +437,6 @@ void GPTDataCurses::MakeNewPart(void) {
    move(LINES - 4, 0);
    clrtobot();
    while ((newFirstLBA < currentSpace->firstLBA) || (newFirstLBA > currentSpace->lastLBA)) {
-      newFirstLBA = currentSpace->firstLBA;
       move(LINES - 4, 0);
       clrtoeol();
       newFirstLBA = currentSpace->firstLBA;
